@@ -842,16 +842,28 @@ impl BluetoothSession {
 
     /// Get a stream of events for all devices.
     pub async fn event_stream(&self) -> Result<impl Stream<Item = BluetoothEvent>, BluetoothError> {
-        self.filtered_event_stream(None::<&DeviceId>).await
+        self.filtered_event_stream(None::<&DeviceId>, true).await
+    }
+
+    /// Get a stream of events for a particular adapter. This includes events for all devices it
+    /// discovers or connects to.
+    pub async fn adapter_event_stream(
+        &self,
+        adapter: &AdapterId,
+    ) -> Result<impl Stream<Item = BluetoothEvent>, BluetoothError> {
+        self.filtered_event_stream(Some(adapter), true).await
     }
 
     /// Get a stream of events for a particular device. This includes events for all its
     /// characteristics.
+    ///
+    /// Note that this will not include the device discovered event for that device, as it is
+    /// considered an event for the adapter rather than the device itself.
     pub async fn device_event_stream(
         &self,
         device: &DeviceId,
     ) -> Result<impl Stream<Item = BluetoothEvent>, BluetoothError> {
-        self.filtered_event_stream(Some(device)).await
+        self.filtered_event_stream(Some(device), false).await
     }
 
     /// Get a stream of events for a particular characteristic of a device.
@@ -859,15 +871,17 @@ impl BluetoothSession {
         &self,
         characteristic: &CharacteristicId,
     ) -> Result<impl Stream<Item = BluetoothEvent>, BluetoothError> {
-        self.filtered_event_stream(Some(characteristic)).await
+        self.filtered_event_stream(Some(characteristic), false)
+            .await
     }
 
     async fn filtered_event_stream(
         &self,
         object: Option<&(impl Into<Path<'static>> + Clone)>,
+        device_discovery: bool,
     ) -> Result<impl Stream<Item = BluetoothEvent>, BluetoothError> {
         let mut message_streams = vec![];
-        for match_rule in BluetoothEvent::match_rules(object.cloned()) {
+        for match_rule in BluetoothEvent::match_rules(object.cloned(), device_discovery) {
             let msg_match = self.connection.add_match(match_rule).await?;
             message_streams.push(MessageStream::new(msg_match, self.connection.clone()));
         }
